{
    "$graph": [
        {
            "class": "Workflow",
            "label": "bam to trimmed fastqs and biscuit alignments",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#main/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "id": "#main/adapter_trim_end"
                },
                {
                    "type": "File",
                    "id": "#main/adapters"
                },
                {
                    "type": "File",
                    "id": "#main/bam"
                },
                {
                    "type": "int",
                    "id": "#main/max_uncalled"
                },
                {
                    "type": "int",
                    "id": "#main/min_readlength"
                },
                {
                    "type": "string",
                    "id": "#main/read_group_id"
                },
                {
                    "type": "string",
                    "id": "#main/reference_index"
                }
            ],
            "steps": [
                {
                    "run": "#bam_to_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/bam",
                            "id": "#main/bam_to_fastq/bam"
                        }
                    ],
                    "out": [
                        "#main/bam_to_fastq/fastq1",
                        "#main/bam_to_fastq/fastq2"
                    ],
                    "id": "#main/bam_to_fastq"
                },
                {
                    "run": "#biscuit_align.cwl",
                    "in": [
                        {
                            "source": "#main/trim_fastq/fastq1",
                            "id": "#main/biscuit_align/fastq1"
                        },
                        {
                            "source": "#main/trim_fastq/fastq2",
                            "id": "#main/biscuit_align/fastq2"
                        },
                        {
                            "source": "#main/read_group_id",
                            "id": "#main/biscuit_align/read_group_id"
                        },
                        {
                            "source": "#main/reference_index",
                            "id": "#main/biscuit_align/reference_index"
                        }
                    ],
                    "out": [
                        "#main/biscuit_align/aligned_bam"
                    ],
                    "id": "#main/biscuit_align"
                },
                {
                    "run": "#biscuit_markdup.cwl",
                    "in": [
                        {
                            "source": "#main/index_bam/indexed_bam",
                            "id": "#main/biscuit_markdup/bam"
                        }
                    ],
                    "out": [
                        "#main/biscuit_markdup/markdup_bam"
                    ],
                    "id": "#main/biscuit_markdup"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#main/biscuit_align/aligned_bam",
                            "id": "#main/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#main/index_bam/indexed_bam"
                    ],
                    "id": "#main/index_bam"
                },
                {
                    "run": "#trim_fastq.cwl",
                    "in": [
                        {
                            "source": "#main/adapter_min_overlap",
                            "id": "#main/trim_fastq/adapter_min_overlap"
                        },
                        {
                            "source": "#main/adapter_trim_end",
                            "id": "#main/trim_fastq/adapter_trim_end"
                        },
                        {
                            "source": "#main/adapters",
                            "id": "#main/trim_fastq/adapters"
                        },
                        {
                            "source": "#main/max_uncalled",
                            "id": "#main/trim_fastq/max_uncalled"
                        },
                        {
                            "source": "#main/min_readlength",
                            "id": "#main/trim_fastq/min_readlength"
                        },
                        {
                            "source": "#main/bam_to_fastq/fastq1",
                            "id": "#main/trim_fastq/reads1"
                        },
                        {
                            "source": "#main/bam_to_fastq/fastq2",
                            "id": "#main/trim_fastq/reads2"
                        }
                    ],
                    "out": [
                        "#main/trim_fastq/fastq1",
                        "#main/trim_fastq/fastq2"
                    ],
                    "id": "#main/trim_fastq"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/biscuit_markdup/markdup_bam",
                    "id": "#main/aligned_bam"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Picard: BAM to FASTQ",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx4g",
                "-jar",
                "/opt/picard/picard.jar",
                "SamToFastq",
                "VALIDATION_STRINGENCY=SILENT"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 6000,
                    "tmpdirMin": 25000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/rnaseq:1.0.0"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "F=$(runtime.outdir)/read1.fastq"
                },
                {
                    "valueFrom": "F2=$(runtime.outdir)/read2.fastq"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I=",
                        "separate": false,
                        "position": 1
                    },
                    "id": "#bam_to_fastq.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read1.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "read2.fastq"
                    },
                    "id": "#bam_to_fastq.cwl/fastq2"
                }
            ],
            "id": "#bam_to_fastq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit: align",
            "baseCommand": [
                "/bin/bash",
                "biscuit_align.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 32000,
                    "coresMin": 12
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "biscuit_align.sh",
                            "entry": "set -eou pipefail\n\ncores=$1\noutdir=\"$2\"\nread_group_id=\"$3\"\nreference_index=\"$4\"\nfastq1=\"$5\"\nfastq2=\"$6\"\n\n/usr/bin/biscuit align -t $cores -M -R \"$read_group_id\" \"$reference_index\" \"$fastq1\" \"$fastq2\" | /usr/bin/sambamba view -S -f bam -l 0 /dev/stdin | /usr/bin/sambamba sort -t $cores -m 8G -o \"$outdir/aligned.bam\" /dev/stdin\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": -9
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -8
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#biscuit_align.cwl/fastq1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#biscuit_align.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#biscuit_align.cwl/read_group_id"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#biscuit_align.cwl/reference_index"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "aligned.bam"
                    },
                    "id": "#biscuit_align.cwl/aligned_bam"
                }
            ],
            "id": "#biscuit_align.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Biscuit dedup",
            "baseCommand": [
                "/bin/bash",
                "biscuit_markdup.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 24000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/biscuit:0.3.8"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "biscuit_markdup.sh",
                            "entry": "set -eou pipefail\n\ncores=$1\noutdir=\"$2\"\nbam=\"$3\"\n\n/usr/bin/biscuit markdup \"$bam\" /dev/stdout | /usr/bin/sambamba sort -t $cores -m 15G -o \"$outdir/markdup.bam\" /dev/stdin\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": -3
                },
                {
                    "valueFrom": "$(runtime.outdir)",
                    "position": -2
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#biscuit_markdup.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "markdup.bam"
                    },
                    "id": "#biscuit_markdup.cwl/markdup_bam"
                }
            ],
            "id": "#biscuit_markdup.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Trim FASTQ (flexbar)",
            "baseCommand": [
                "/opt/flexbar/flexbar"
            ],
            "arguments": [
                "--target",
                {
                    "valueFrom": "$(runtime.outdir)/trimmed_read"
                },
                "--threads",
                {
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 16000,
                    "tmpdirMin": 25000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bisulfite:v1.4"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--adapter-min-overlap",
                        "position": 3
                    },
                    "id": "#trim_fastq.cwl/adapter_min_overlap"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--adapter-trim-end",
                        "position": 2
                    },
                    "id": "#trim_fastq.cwl/adapter_trim_end"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--adapters",
                        "position": 1
                    },
                    "id": "#trim_fastq.cwl/adapters"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--max-uncalled",
                        "position": 5
                    },
                    "id": "#trim_fastq.cwl/max_uncalled"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--min-read-length",
                        "position": 6
                    },
                    "id": "#trim_fastq.cwl/min_readlength"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads",
                        "position": 7
                    },
                    "id": "#trim_fastq.cwl/reads1"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--reads2",
                        "position": 8
                    },
                    "id": "#trim_fastq.cwl/reads2"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_1.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq1"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "trimmed_read_2.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastq2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "trimmed_read_*.fastq"
                    },
                    "id": "#trim_fastq.cwl/fastqs"
                }
            ],
            "id": "#trim_fastq.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
